@@ -9,7 +9,7 @@ Types::Core - Core types defined as tests and literals (ease of use)
 
 =head1 VERSION
 
-Version "0.1.5";
+Version "0.1.6";
 
 =cut
 
@@ -19,11 +19,12 @@ Version "0.1.5";
 	use strict;
 	use warnings;
 	use mem;
-	our $VERSION='0.1.5';
+	our $VERSION='0.1.6';
 
+# 0.1.6 - Needed to split a statement that parsed in a different order under
+#         5.8.x
 # 0.1.5 - Added code and test case to handle type-named classes
 # 			- use Scalar::Utils for blessed and 'ref' if available.
-# 			
 # 0.1.4 - Add BUILD_REQ for more modern Ext:MM
 # 0.1.3 - investigate fails on perl 5.12.x: 
 # 				- changed prototypes on single arg tests to use '$' instead of '*';
@@ -91,7 +92,7 @@ Version "0.1.5";
 		if ($Use_Scalar_Util) {
 
 			eval '# line ' . __LINE__ .' '. __FILE__ .' 
-			sub _type ($) { Scalar::Util::reftype $_[0] }
+			sub _type ($) { Scalar::Util::reftype($_[0]) }
 			sub _isatype ($$) { (typ($_[0])//"") eq ($_[1]//"") ? $_[0] : undef };
 			sub blessed ($) { Scalar::Util::blessed($_[0]) ? $_[0] : undef }';
 
@@ -100,10 +101,11 @@ Version "0.1.5";
 		} else {
 				
 			eval '# line ' . __LINE__ .' '. __FILE__ .' 
-				sub _type ($) { my $start;
+				sub _type ($) {
 					my $end = index $_[0], "(";
 					return undef unless $end > '. &last_let_offset .';
-					substr $_[0], $start=1+rindex($_[0], "=", $end), $end-$start; 
+					my $start	= 1+rindex($_[0], "=", $end);
+					substr $_[0], $start, $end-$start; 
 				}
 					
 				sub _isatype($$) {
